Package: eClosure
Type: Package
Title: Methods Based on the e-Closure Principle
Version: 0.9.5
Authors@R: c(
    person(
      "Jelle", "Goeman",
      email = "j.j.goeman@lumc.nl",
      role = c("aut", "cre")
    )
  )
Maintainer: Jelle Goeman <j.j.goeman@lumc.nl>
Description: Implements several methods for False Discovery Rate control based on the e-Closure Principle,
  in particular the Closed e-Benjamini-Hochberg and Closed Benjamini-Yekutieli procedures.
License: GPL-3
Imports: Rcpp
LinkingTo: Rcpp
NeedsCompilation: yes
Encoding: UTF-8
Suggests: testthat (>= 3.0.0)
Config/testthat/edition: 3
Config/roxygen2/version: 8.0.0
Packaged: 2026-06-01 13:12:07 UTC; jjgoeman
Author: Jelle Goeman [aut, cre]
Repository: CRAN
Date/Publication: 2026-06-01 13:30:02 UTC
Built: R 4.6.0; aarch64-apple-darwin23; 2026-06-01 15:23:29 UTC; unix
Archs: eClosure.so.dSYM
