# Generated by roxygen2: do not edit by hand

export(closedBH)
export(closedBH.adjust)
export(closedBY)
export(closedSu)
export(closedeBH)
importFrom(Rcpp,sourceCpp)
useDynLib(eClosure, .registration = TRUE)
